==> ragrank-0.0.1.tar.gz: ragrank-0.0.1/README.md <==
<p align="center">
    <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://raw.githubusercontent.com/Auto-Playground/Ragrank/main/docs/docs/_static/imgs/ragrank_dark.png">
    <source media="(prefers-color-scheme: light)" srcset="https://raw.githubusercontent.com/Auto-Playground/Ragrank/main/docs/docs/_static/imgs/ragrank_light.png">
    <img alt="Hashnode logo" src="https://raw.githubusercontent.com/Auto-Playground/Ragrank/main/docs/docs/_static/imgs/ragrank_light.png" height="130">
    </picture>
    <br/>
    <br/>
</p>

<p align="center">
    <a href="https://circleci.com/gh/huggingface/transformers">
        <img alt="Build" src="https://img.shields.io/badge/PyPI-v0.1.2-blue.svg">
    </a>
    <a href="https://github.com/huggingface/transformers/blob/main/LICENSE">
        <img alt="GitHub" src="https://img.shields.io/badge/Build-passing-green.svg">
    </a>
    <a href="https://github.com/huggingface/transformers/blob/main/LICENSE">
        <img alt="GitHub" src="https://img.shields.io/badge/Build with-Python-yellow.svg">
    </a>
</p>

Welcome to Ragrank! This toolkit is designed to assist you in evaluating the performance of your LLM applications. Whether you're working on chatbots, text generators, or any other natural language processing (NLP) task, our toolkit can help you assess various aspects of your model's performance.

## What does it do?

Our free LLM evaluation toolkit offers functionalities to assess:

- **Accuracy of Facts:** Evaluate how accurately your model generates factual information.
- **Understanding of Context:** Measure how well your model comprehends and maintains context within a conversation or text.
- **Tone Analysis:** Analyze the tone of generated text to ensure it aligns with your desired tone or sentiment.
- **And More:** Additional evaluation metrics and functionalities to help you gauge the effectiveness of your LLM applications.

## How to Use

1. **Installation:** Clone or download this repository to your local machine.

2. **Usage:** Utilize the provided evaluation scripts and tools to evaluate your LLM applications. Detailed instructions for each evaluation metric are included within their respective directories.

3. **Customization:** Feel free to customize and extend the toolkit to suit your specific evaluation needs. Contributions and feedback are welcomed!

## Contributing

If you'd like to contribute to the LLM Evaluation Toolkit, please follow these steps:

1. Fork this repository.
2. Create a new branch (`git checkout -b feature/improvement`).
3. Make your changes.
4. Commit your changes (`git commit -am 'Add new feature'`).
5. Push to the branch (`git push origin feature/improvement`).
6. Create a new Pull Request.

## License

This project is licensed under the [Apatche Licence](LICENSE).

## Feedback and Support

If you encounter any issues, have questions, or would like to provide feedback, please open an issue on the GitHub repository.

Happy evaluating!

==> ragrank-0.0.3.tar.gz: ragrank-0.0.3/README.md <==
<p align="center">
    <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://raw.githubusercontent.com/Auto-Playground/Ragrank/main/docs/docs/_static/imgs/ragrank_dark.png">
    <source media="(prefers-color-scheme: light)" srcset="https://raw.githubusercontent.com/Auto-Playground/Ragrank/main/docs/docs/_static/imgs/ragrank_light.png">
    <img alt="Hashnode logo" src="https://raw.githubusercontent.com/Auto-Playground/Ragrank/main/docs/docs/_static/imgs/ragrank_light.png" height="130">
    </picture>

</p>

<p align="center">
    <a href="">
        <img alt="GitHub" src="https://img.shields.io/github/license/Auto-Playground/ragrank">
    </a>
    <a href="https://pypi.org/project/ragrank/">
        <img alt="Build" src="https://img.shields.io/pypi/pyversions/ragrank">
    </a>
    <a href="https://ragrank.readthedocs.io/latest/">
        <img alt="GitHub" src="https://img.shields.io/readthedocs/ragrank">
    </a>
    <a href="https://pypi.org/project/ragrank/">
        <img alt="GitHub" src="https://img.shields.io/github/v/release/Auto-Playground/Ragrank?color=orange">
    </a>
    <a href="https://github.com/Auto-Playground/Ragrank/actions">
        <img alt="GitHub" src="https://img.shields.io/github/actions/workflow/status/Auto-Playground/ragrank/.github%2Fworkflows%2Ftests.yml">
    </a>
</p>

<h4 align="center">
    <p>
        <a href="https://ragrank.readthedocs.io/latest/">Documentation</a> |
        <a href="https://api-ragrank.readthedocs.io/">API reference</a> |
        <a href="https://ragrank.readthedocs.io/latest/get_started/basic_evaluation.html">Quickstart</a> |
        <a href="https://discord.gg/yaFRx6ja">Join the Community</a>
    <p>
</h4>

Welcome to Ragrank! This toolkit is designed to assist you in evaluating the performance of your LLM applications. Whether you're working on chatbots, text generators, or any other natural language processing (NLP) task, our toolkit can help you assess various aspects of your model's performance.

## What does it do?

Our free LLM evaluation toolkit offers functionalities to assess:

- **Accuracy of Facts:** Evaluate how accurately your model generates factual information.
- **Understanding of Context:** Measure how well your model comprehends and maintains context within a conversation or text.
- **Tone Analysis:** Analyze the tone of generated text to ensure it aligns with your desired tone or sentiment.
- **And More:** Additional evaluation metrics and functionalities to help you gauge the effectiveness of your LLM applications.

## How to Use

1. **Installation:** Clone or download this repository to your local machine.

2. **Usage:** Utilize the provided evaluation scripts and tools to evaluate your LLM applications. Detailed instructions for each evaluation metric are included within their respective directories.

3. **Customization:** Feel free to customize and extend the toolkit to suit your specific evaluation needs. Contributions and feedback are welcomed!

## Contributing

If you'd like to contribute to the LLM Evaluation Toolkit, please follow these steps:

1. Fork this repository.
2. Create a new branch (`git checkout -b feature/improvement`).
3. Make your changes.
4. Commit your changes (`git commit -am 'Add new feature'`).
5. Push to the branch (`git push origin feature/improvement`).
6. Create a new Pull Request.

## License

This project is licensed under the [Apatche Licence](https://github.com/Auto-Playground/Ragrank/blob/main/LICENSE).

## Feedback and Support

If you encounter any issues, have questions, or would like to provide feedback, please open an issue on the GitHub repository.

Happy evaluating!
